@@ -189,38 +189,17 @@ def process_data(*, num_threads: int, test_images: bool, test_output_dir: str,
 
 
 if __name__ == '__main__':
-    # process_data(num_threads=1, load_data=True,
-    #              data_path="/home/sam/Desktop/LSSC-python/input_images" +
-    #                        "/small_dataset.tif",
-    #              test_images=True,
-    #              test_output_dir="/home/sam/Desktop/LSSC-python/output_images/15",
-    #              image_data=None,
-    #              total_num_time_steps=4, total_num_spatial_boxes=4, spatial_overlap=10,
-    #              filter=True, median_filter_size=(1, 3, 3), median_filter=True,
-    #              z_score=False, slice_stack=False, slice_every=1, slice_start=0,
-    #              metric="l2", knn=50, accuracy=50, connections=60,
-    #              num_eig=25, normalize_w_k=2, merge=True,
-    #              num_rois=25, refinement=True,
-    #              num_eigen_vector_select=5,
-    #              max_iter=1000, roi_size_threshold=30,
-    #              fill_holes=True,
-    #              elbow_threshold_method=True,
-    #              elbow_threshold_value=1,
-    #              eigen_threshold_method=True,
-    #              eigen_threshold_value=.5,
-    #              merge_temporal_coef=.01,
-    #              roi_size_limit=600)
-    # with performance_report(filename="dask-report.html"):
     process_data(num_threads=1, load_data=True,
-                 data_path="/Users/sschickler/Code Devel/LSSC-python/input_images/dataset_1",
-                 test_images=False,
-                 test_output_dir="/Users/sschickler/Documents/LSSC-python/output_images/16",
-                 image_data=None,
-                 save_dir="/Users/sschickler/Code DEvel/LSSC-python/output_images/16",
-                 save_embedding_images=True,
-                 save_intermediate_steps=True,
+                 data_path="/Users/sschickler/Code Devel/LSSC-python/input_images" +
+                           "/small_dataset.tif",
+                 test_images=True,
+                 save_dir="/Users/sschickler/Code Devel/LSSC-python/output_images/15",
+                 save_intermediate_steps=False,
                  eigen_vectors_already_generated=False,
-                 total_num_time_steps=20, total_num_spatial_boxes=16, spatial_overlap=30,
+                 save_embedding_images=False,
+                 test_output_dir="/Users/sschickler/Code Devel/LSSC-python/output_images/15",
+                 image_data=None,
+                 total_num_time_steps=4, total_num_spatial_boxes=4, spatial_overlap=10,
                  filter=True, median_filter_size=(1, 3, 3), median_filter=True,
                  z_score=False, slice_stack=False, slice_every=10, slice_start=0,
                  metric="l2", knn=50, accuracy=59, connections=60,
@@ -234,4 +213,29 @@ if __name__ == '__main__':
                  eigen_threshold_method=True,
                  eigen_threshold_value=.5,
                  merge_temporal_coef=.01,
-                 roi_size_max=600)
\ No newline at end of file
+                 roi_size_max=600)
+    # with performance_report(filename="dask-report.html"):
+    # process_data(num_threads=1, load_data=True,
+    #              data_path="/Users/sschickler/Code Devel/LSSC-python/input_images/dataset_1",
+    #              test_images=False,
+    #              test_output_dir="/Users/sschickler/Documents/LSSC-python/output_images/16",
+    #              image_data=None,
+    #              save_dir="/Users/sschickler/Code DEvel/LSSC-python/output_images/16",
+    #              save_embedding_images=True,
+    #              save_intermediate_steps=True,
+    #              eigen_vectors_already_generated=False,
+    #              total_num_time_steps=20, total_num_spatial_boxes=16, spatial_overlap=30,
+    #              filter=True, median_filter_size=(1, 3, 3), median_filter=True,
+    #              z_score=False, slice_stack=False, slice_every=10, slice_start=0,
+    #              metric="l2", knn=50, accuracy=59, connections=60,
+    #              num_eig=50, normalize_w_k=2, merge=True,
+    #              num_rois=25, refinement=True,
+    #              num_eigen_vector_select=5,
+    #              max_iter=400, roi_size_min=30,
+    #              fill_holes=True,
+    #              elbow_threshold_method=True,
+    #              elbow_threshold_value=1,
+    #              eigen_threshold_method=True,
+    #              eigen_threshold_value=.5,
+    #              merge_temporal_coef=.01,
+    #              roi_size_max=600)
\ No newline at end of file
